@@ -7,7 +7,6 @@ import (
 
 	"github.com/ovn-org/libovsdb/ovsdb"
 	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
 )
 
 var (
@@ -77,7 +76,8 @@ var testSchema = []byte(`{
               "refType": "weak",
               "type": "uuid"
             },
-            "min": 0
+            "min": 0,
+            "max": "unlimited"
           }
         },
         "aUUID": {
@@ -187,7 +187,7 @@ func TestMapperGetData(t *testing.T) {
 	type ormTestType struct {
 		AString             string            `ovsdb:"aString"`
 		ASet                []string          `ovsdb:"aSet"`
-		ASingleSet          []string          `ovsdb:"aSingleSet"`
+		ASingleSet          *string           `ovsdb:"aSingleSet"`
 		AUUIDSet            []string          `ovsdb:"aUUIDSet"`
 		AUUID               string            `ovsdb:"aUUID"`
 		AIntSet             []int             `ovsdb:"aIntSet"`
@@ -202,7 +202,7 @@ func TestMapperGetData(t *testing.T) {
 	var expected = ormTestType{
 		AString:             aString,
 		ASet:                aSet,
-		ASingleSet:          []string{aString},
+		ASingleSet:          &aString,
 		AUUIDSet:            aUUIDSet,
 		AUUID:               aUUID0,
 		AIntSet:             aIntSet,
@@ -221,11 +221,15 @@ func TestMapperGetData(t *testing.T) {
 		t.Error(err)
 	}
 
-	mapper := NewMapper(&schema)
+	mapper := NewMapper(schema)
 	test := ormTestType{
 		NonTagged: "something",
 	}
-	err := mapper.GetRowData("TestTable", &ovsRow, &test)
+	testInfo, err := NewInfo("TestTable", schema.Table("TestTable"), &test)
+	assert.NoError(t, err)
+
+	err = mapper.GetRowData(&ovsRow, testInfo)
+	assert.NoError(t, err)
 	/*End code under test*/
 
 	if err != nil {
@@ -339,13 +343,15 @@ func TestMapperNewRow(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(fmt.Sprintf("NewRow: %s", test.name), func(t *testing.T) {
-			mapper := NewMapper(&schema)
-			row, err := mapper.NewRow("TestTable", test.objInput)
+			mapper := NewMapper(schema)
+			info, err := NewInfo("TestTable", schema.Table("TestTable"), test.objInput)
+			assert.NoError(t, err)
+			row, err := mapper.NewRow(info)
 			if test.shoulderr {
 				assert.NotNil(t, err)
 			} else {
 				assert.Nil(t, err)
-				assert.Equalf(t, test.expectedRow, row, "NewRow should match expeted")
+				assert.Equalf(t, test.expectedRow, row, "NewRow should match expected")
 			}
 		})
 	}
@@ -423,7 +429,7 @@ func TestMapperNewRowFields(t *testing.T) {
 
 	for _, test := range tests {
 		t.Run(fmt.Sprintf("NewRow: %s", test.name), func(t *testing.T) {
-			mapper := NewMapper(&schema)
+			mapper := NewMapper(schema)
 			// Clean the test object
 			testObj.MyString = ""
 			testObj.MyMap = nil
@@ -431,12 +437,14 @@ func TestMapperNewRowFields(t *testing.T) {
 			testObj.MyFloat = 0
 
 			test.prepare(&testObj)
-			row, err := mapper.NewRow("TestTable", &testObj, test.fields...)
+			info, err := NewInfo("TestTable", schema.Table("TestTable"), &testObj)
+			assert.NoError(t, err)
+			row, err := mapper.NewRow(info, test.fields...)
 			if test.err {
 				assert.NotNil(t, err)
 			} else {
 				assert.Nil(t, err)
-				assert.Equalf(t, test.expectedRow, row, "NewRow should match expeted")
+				assert.Equalf(t, test.expectedRow, row, "NewRow should match expected")
 			}
 		})
 	}
@@ -488,7 +496,7 @@ func TestMapperCondition(t *testing.T) {
 	if err := json.Unmarshal(testSchema, &schema); err != nil {
 		t.Fatal(err)
 	}
-	mapper := NewMapper(&schema)
+	mapper := NewMapper(schema)
 
 	type Test struct {
 		name     string
@@ -583,7 +591,10 @@ func TestMapperCondition(t *testing.T) {
 	for _, tt := range tests {
 		t.Run(fmt.Sprintf("newEqualityCondition_%s", tt.name), func(t *testing.T) {
 			tt.prepare(&testObj)
-			conds, err := mapper.NewEqualityCondition("TestTable", &testObj, tt.index...)
+			info, err := NewInfo("TestTable", schema.Table("TestTable"), &testObj)
+			assert.NoError(t, err)
+
+			conds, err := mapper.NewEqualityCondition(info, tt.index...)
 			if tt.err {
 				if err == nil {
 					t.Errorf("expected an error but got none")
@@ -659,7 +670,7 @@ func TestMapperEqualIndexes(t *testing.T) {
 	if err := json.Unmarshal(testSchema, &schema); err != nil {
 		t.Fatal(err)
 	}
-	mapper := NewMapper(&schema)
+	mapper := NewMapper(schema)
 
 	type Test struct {
 		name     string
@@ -834,7 +845,11 @@ func TestMapperEqualIndexes(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(fmt.Sprintf("Equal %s", test.name), func(t *testing.T) {
-			eq, err := mapper.equalIndexes(mapper.Schema.Table("TestTable"), &test.obj1, &test.obj2, test.indexes...)
+			info1, err := NewInfo("TestTable", schema.Table("TestTable"), &test.obj1)
+			assert.NoError(t, err)
+			info2, err := NewInfo("TestTable", schema.Table("TestTable"), &test.obj2)
+			assert.NoError(t, err)
+			eq, err := mapper.equalIndexes(info1, info2, test.indexes...)
 			assert.Nil(t, err)
 			assert.Equalf(t, test.expected, eq, "equal value should match expected")
 		})
@@ -857,11 +872,15 @@ func TestMapperEqualIndexes(t *testing.T) {
 		Int1:   42,
 		Int2:   25,
 	}
-	eq, err := mapper.EqualFields("TestTable", &obj1, &obj2, &obj1.Int1, &obj1.Int2)
+	info1, err := NewInfo("TestTable", schema.Table("TestTable"), &obj1)
+	assert.NoError(t, err)
+	info2, err := NewInfo("TestTable", schema.Table("TestTable"), &obj2)
+	assert.NoError(t, err)
+	eq, err := mapper.EqualFields(info1, info2, &obj1.Int1, &obj1.Int2)
 	assert.Nil(t, err)
 	assert.True(t, eq)
 	// Using pointers to second value is not supported
-	_, err = mapper.EqualFields("TestTable", &obj1, &obj2, &obj2.Int1, &obj2.Int2)
+	_, err = mapper.EqualFields(info1, info2, &obj2.Int1, &obj2.Int2)
 	assert.NotNil(t, err)
 
 }
@@ -880,7 +899,8 @@ func TestMapperMutation(t *testing.T) {
         "set": {
           "type": {
             "key": "string",
-            "min": 0
+            "min": 0,
+            "max": "unlimited"
           }
         },
         "map": {
@@ -890,11 +910,11 @@ func TestMapperMutation(t *testing.T) {
           }
         },
         "unmutable": {
-	  "mutable": false,
+          "mutable": false,
           "type": {
             "key": "integer"
           }
-	},
+	      },
         "int": {
           "type": {
             "key": "integer"
@@ -917,7 +937,7 @@ func TestMapperMutation(t *testing.T) {
 	if err := json.Unmarshal(testSchema, &schema); err != nil {
 		t.Fatal(err)
 	}
-	mapper := NewMapper(&schema)
+	mapper := NewMapper(schema)
 
 	type Test struct {
 		name     string
@@ -963,7 +983,7 @@ func TestMapperMutation(t *testing.T) {
 			err:     true,
 		},
 		{
-			name:     "Add elemet to set ",
+			name:     "Add element to set ",
 			column:   "set",
 			obj:      testType{},
 			mutator:  ovsdb.MutateOperationInsert,
@@ -981,7 +1001,7 @@ func TestMapperMutation(t *testing.T) {
 			err:      false,
 		},
 		{
-			name:     "Delete elements from map ",
+			name:     "Delete keys from map ",
 			column:   "map",
 			obj:      testType{},
 			mutator:  ovsdb.MutateOperationDelete,
@@ -989,6 +1009,15 @@ func TestMapperMutation(t *testing.T) {
 			expected: ovsdb.NewMutation("map", ovsdb.MutateOperationDelete, testOvsSet(t, []string{"foo", "bar"})),
 			err:      false,
 		},
+		{
+			name:     "Delete key value pairs from map ",
+			column:   "map",
+			obj:      testType{},
+			mutator:  ovsdb.MutateOperationDelete,
+			value:    map[string]string{"foo": "bar"},
+			expected: ovsdb.NewMutation("map", ovsdb.MutateOperationDelete, testOvsMap(t, map[string]string{"foo": "bar"})),
+			err:      false,
+		},
 		{
 			name:     "Insert elements in map ",
 			column:   "map",
@@ -1001,7 +1030,10 @@ func TestMapperMutation(t *testing.T) {
 	}
 	for _, test := range tests {
 		t.Run(fmt.Sprintf("newMutation%s", test.name), func(t *testing.T) {
-			mutation, err := mapper.NewMutation("TestTable", &test.obj, test.column, test.mutator, test.value)
+			info, err := NewInfo("TestTable", schema.Table("TestTable"), &test.obj)
+			assert.NoError(t, err)
+
+			mutation, err := mapper.NewMutation(info, test.column, test.mutator, test.value)
 			if test.err {
 				if err == nil {
 					t.Errorf("expected an error but got none")
@@ -1028,68 +1060,3 @@ func testOvsMap(t *testing.T, set interface{}) ovsdb.OvsMap {
 	assert.Nil(t, err)
 	return oMap
 }
-
-func TestNewMonitorRequest(t *testing.T) {
-	var testSchema = []byte(`{
-  "cksum": "223619766 22548",
-  "name": "TestSchema",
-  "tables": {
-    "TestTable": {
-      "indexes": [["name"],["composed_1","composed_2"]],
-      "columns": {
-        "name": {
-          "type": "string"
-        },
-        "composed_1": {
-          "type": {
-            "key": "string"
-          }
-        },
-        "composed_2": {
-          "type": {
-            "key": "string"
-          }
-        },
-        "int1": {
-          "type": {
-            "key": "integer"
-          }
-        },
-        "int2": {
-          "type": {
-            "key": "integer"
-          }
-        },
-        "config": {
-          "type": {
-            "key": "string",
-            "max": "unlimited",
-            "min": 0,
-            "value": "string"
-          }
-	}
-      }
-    }
-  }
-}`)
-	type testType struct {
-		ID     string            `ovsdb:"_uuid"`
-		MyName string            `ovsdb:"name"`
-		Config map[string]string `ovsdb:"config"`
-		Comp1  string            `ovsdb:"composed_1"`
-		Comp2  string            `ovsdb:"composed_2"`
-		Int1   int               `ovsdb:"int1"`
-		Int2   int               `ovsdb:"int2"`
-	}
-	var schema ovsdb.DatabaseSchema
-	err := json.Unmarshal(testSchema, &schema)
-	require.NoError(t, err)
-	mapper := NewMapper(&schema)
-	testTable := &testType{}
-	mr, err := mapper.NewMonitorRequest("TestTable", testTable, nil)
-	require.NoError(t, err)
-	assert.ElementsMatch(t, mr.Columns, []string{"name", "config", "composed_1", "composed_2", "int1", "int2"})
-	mr2, err := mapper.NewMonitorRequest("TestTable", testTable, []interface{}{&testTable.Int1, &testTable.MyName})
-	require.NoError(t, err)
-	assert.ElementsMatch(t, mr2.Columns, []string{"int1", "name"})
-}
