@@ -20,6 +20,8 @@ var (
 	aUUID2   = "2f77b348-9768-4866-b761-89d5177ecda2"
 	aUUID3   = "2f77b348-9768-4866-b761-89d5177ecda3"
 
+	aSingleUUIDSet, _ = NewOvsSet(UUID{GoUUID: aUUID0})
+
 	aUUIDSet = []string{
 		aUUID0,
 		aUUID1,
@@ -87,6 +89,8 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 		"key3": {GoUUID: aUUID2},
 	})
 
+	singleStringSet, _ := NewOvsSet([]string{"foo"})
+
 	tests := []struct {
 		name   string
 		schema []byte
@@ -164,7 +168,8 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 					"refType": "weak",
 					"type": "uuid"
 				},
-				"min": 0
+				"min": 0,
+				"max": "unlimited"
 				}
 			}`),
 			input:  uss,
@@ -180,7 +185,8 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 						"refType": "weak",
 						"type": "uuid"
 					},
-					"min": 0
+					"min": 0,
+					"max": "unlimited"
 					}
 			}`),
 			input:  UUID{GoUUID: aUUID0},
@@ -356,6 +362,70 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 			native: aUUIDMap,
 			ovs:    um,
 		},
+		{
+			name: "String set with min 0 max 1",
+			schema: []byte(`{
+			"type":{
+				"key": {
+				"type": "string"
+				},
+				"min": 0,
+				"max": 1
+			}
+			}`),
+			input:  singleStringSet,
+			native: &aString,
+			ovs:    singleStringSet,
+		},
+		{
+			name: "UUID set with min 0 max 1",
+			schema: []byte(`{
+			"type":{
+				"key": {
+					"refTable": "SomeOtherTAble",
+					"refType": "weak",
+					"type": "uuid"
+				},
+				"min": 0,
+				"max": 1
+			}
+			}`),
+			input:  aSingleUUIDSet,
+			native: &aUUID0,
+			ovs:    aSingleUUIDSet,
+		},
+		{
+			name: "null UUID set with min 0 max 1",
+			schema: []byte(`{
+			"type":{
+				"key": {
+					"refTable": "SomeOtherTAble",
+					"refType": "weak",
+					"type": "uuid"
+				},
+				"min": 0,
+				"max": 1
+			}
+			}`),
+			input:  es,
+			native: (*string)(nil),
+			ovs:    es,
+		},
+		{
+			name: "A string with min 0 max 1",
+			schema: []byte(`{
+			"type":{
+				"key": {
+				"type": "string"
+				},
+				"min": 0,
+				"max": 1
+			}
+			}`),
+			input:  aString,
+			native: &aString,
+			ovs:    singleStringSet,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -364,9 +434,9 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 			require.NoError(t, err)
 
 			native, err := OvsToNative(&column, tt.input)
-			require.NoErrorf(t, err, "failed to convert %+v: %s", tt, err)
+			require.NoError(t, err)
 
-			require.Equalf(t, native, tt.native,
+			require.Equalf(t, tt.native, native,
 				"fail to convert ovs2native. input: %v(%s). expected %v(%s). got %v (%s)",
 				tt.input, reflect.TypeOf(tt.input),
 				tt.native, reflect.TypeOf(tt.native),
@@ -376,7 +446,7 @@ func TestOvsToNativeAndNativeToOvs(t *testing.T) {
 			ovs, err := NativeToOvs(&column, native)
 			require.NoErrorf(t, err, "failed to convert %s: %s", tt, err)
 
-			assert.Equalf(t, ovs, tt.ovs,
+			assert.Equalf(t, tt.ovs, ovs,
 				"fail to convert native2ovs. native: %v(%s). expected %v(%s). got %v (%s)",
 				native, reflect.TypeOf(native),
 				tt.ovs, reflect.TypeOf(tt.ovs),
